;+
;
; .. _interp_olr_30n30s_1989_2009.pro:
;
; ===============================
; interp_olr_30n30s_1989_2009.pro
; ===============================
;
;
; SEE ALSO
; ========
;
; EXAMPLES
; ========
;
; ::
;
;  IDL> interp_olr_30n30s_1989_2009
;
; TODO
; ====
;
; hard coded directory - usage of ${TROPFLUX_ID}
;
; coding rules
;
; EVOLUTIONS
; ==========
;
; - fplod 20101214T093615Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
; - pbk 2008
;
;   * creation
;
;-
pro interp_olr_30n30s_1989_2009
@common

filein='/Users/pkb/data/heat_budget/NOAA_OLR/new/olr.day.mean_new.nc'
gridout='/Volumes/PRAVEEN/work/flux_reconstruction/gridded_data/mask_oaflux_30N30S.nc'

initncdf, filein
domdef
latin=reform(gphit(0,*)) & lonin=reform(glamt(*,0))
print, 'lat grid ',min(latin),max(latin),latin(1)-latin(0)
print, 'lon grid ',min(lonin),max(lonin),lonin(1)-lonin(0)
olrin=read_ncdf("olr",19881231, 20091231, file=filein,/nostr)

mskin=glamt*0.+1.

timein=time & jptin=jpt

initncdf, gridout
domdef
latout=reform(gphit(0,*)) & lonout=reform(glamt(*,0))
print, 'lat grid ',min(latout),max(latout),latout(1)-latout(0)
print, 'lon grid ',min(lonout),max(lonout),lonout(1)-lonout(0)
mskout=read_ncdf("msk", file=gridout,/nostr)

help, olrin,lonin,latin,mskin,lonout,latout,mskout

olrout=fltarr(jpi,jpj,jptin)

for jt=0,jptin-1 do begin

  print, 'Interpolation jt=',jt,' / ',jptin-1
  tab_olr=reform(olrin(*,*,jt))

  olrout(*,*,jt)=call_interp2d(tab_olr,lonin,latin,mskin,lonout,latout,method='bilinear')

  olrout(*,*,jt)=olrout(*,*,jt)*mskout+(1.-mskout)*1.e20

endfor


timein=timein & jptin=jpt

timein=timein-julday(1,1,1950,00,00)

lat=latout
lon=lonout
ncfile='!/Users/pkb/data/heat_budget/NOAA_OLR/newolr_oafluxgrid_30n30s_19890101_20091231.nc'
lon_attr={units:'degrees_east',long_name:'Longitude'}
lat_attr={units:'degrees_north',long_name:'Latitude'}
time_attr={units:'days since 1950-01-01 00:00:00',long_name:'Time axis',time_origin:' 1950-JAN-01 00:00:00'}
olr_attr={units:'w/m^2',missing_value:1e20,long_name:'Outgoing Longwave Radiation',short_name:'olr',axis:'TYX'}
olra_attr={units:'w/m^2',missing_value:1e20,long_name:'Outgoing Longwave Radiation Anomaly',short_name:'olra',axis:'TYX'}
globattr={source:'NOAA OLR, cf http://www.cdc.noaa.gov/cdc/data.interp_OLR.html, interpolated to 1x1 degree grid and with oaflux mask'}


ncfields = 'olr[longitude,latitude,time]=olrout:olr_attr; ' $
                      + 'longitude[]=lon:lon_attr; ' $
                      + 'latitude[]=lat:lat_attr; ' $
                      + 'time[*time]=timein:time_attr ' $
                      + ' @ globattr'

@ncdf_quickwrite


end
